@@ -429,8 +429,9 @@ public class EntityMaintainer
 		catch (Exception e)
 		{
 			System.err.println("Error: failed to repair sentence.");
-			System.err.println("Borken sentence was:");
+			System.err.println("Broken sentence was: "+getOriginalSentence());
 			System.err.println(RawView.printZHeads(leftNode));
+			e.printStackTrace();
 		}
 	}
 
@@ -452,6 +453,17 @@ public class EntityMaintainer
 		}
 	}
 
+	public String toString(){
+		StringBuilder sb = new StringBuilder();
+		for (EntityInfo info: orderedEntityInfos){
+			String name = info.getOriginalSentence().substring(
+					info.getFirstCharIndex(), 
+					info.getLastCharIndex());
+			sb.append(makeID(info)).append(": ").append(name).append("\n");
+		}
+		return sb.toString();
+	}
+	
 	public static void main(String[] args)
 	{
 		/*
